@@ -343,6 +343,9 @@ func NewCreateClusterLoader(cmd *Cmd, ngFilter *filter.NodeGroupFilter, ng *api.
 		}
 
 		for _, ng := range l.ClusterConfig.ManagedNodeGroups {
+			if err := validateUnsupportedCLIFeatures(ng); err != nil {
+				return err
+			}
 			ng.Name = names.ForNodeGroup(ng.Name, "")
 		}
 
@@ -400,6 +403,9 @@ func NewCreateNodeGroupLoader(cmd *Cmd, ng *api.NodeGroup, ngFilter *filter.Node
 		// Validate both filtered and unfiltered nodegroups
 		if mngOptions.Managed {
 			for _, ng := range l.ClusterConfig.ManagedNodeGroups {
+				if err := validateUnsupportedCLIFeatures(ng); err != nil {
+					return err
+				}
 				ngName := names.ForNodeGroup(ng.Name, l.NameArg)
 				if ngName == "" {
 					return ErrFlagAndArg("--name", ng.Name, l.NameArg)
@@ -439,6 +445,14 @@ func makeManagedNodegroup(nodeGroup *api.NodeGroup, options CreateManagedNGOptio
 	}
 }
 
+func validateUnsupportedCLIFeatures(ng *api.ManagedNodeGroup) error {
+	if api.IsWindowsImage(ng.AMIFamily) {
+		return errors.New("Windows is not supported for managed nodegroups; eksctl now creates " +
+			"managed nodegroups by default, to use a self-managed nodegroup, pass --managed=false")
+	}
+	return nil
+}
+
 func validateManagedNGFlags(cmd *cobra.Command, managed bool) error {
 	if managed {
 		return nil
